@@ -135,6 +135,16 @@ def test_days_overflow_correctly(ts):
         '2020-10-02', '2020-11-01', '2020-12-02', '2021-01-01',
     ]
 
+def test_sequence_behaviors_of_time_that_is_not_array(ts):
+    t = ts.utc(2023, 4, 2)
+    with assert_raises(TypeError):
+        for item in t:
+            pass
+    # The specific exception TypeError in the following case makes
+    # Pandas inference.is_sequence() happy.
+    with assert_raises(TypeError):
+        len(t)
+
 def test_time_can_be_indexed(ts):
     for t in all_kinds_of_time_array(ts):
         t[0]
@@ -736,3 +746,20 @@ def test_time_equality(ts):
     assert t2 != t0
     assert t2 - t0 > 0
     assert hash(t0) != hash(t2)
+
+def test_time_math(ts):
+    t = ts.tt_jd(2459008.5, 0.125)
+
+    assert (t - 1).tt_strftime() == '2020-06-07 03:00:00 TT'
+    assert (t + 1).tt_strftime() == '2020-06-09 03:00:00 TT'
+
+    assert (t - 1.25).tt_strftime() == '2020-06-06 21:00:00 TT'
+    assert (t + 1.25).tt_strftime() == '2020-06-09 09:00:00 TT'
+
+    bump = dt_module.timedelta(days=1, seconds=1)
+    assert (t - bump).tt_strftime() == '2020-06-07 02:59:59 TT'
+    assert (t + bump).tt_strftime() == '2020-06-09 03:00:01 TT'
+
+    bump = dt_module.timedelta(microseconds=300)
+    assert (t - bump).utc_jpl() == 'A.D. 2020-Jun-08 02:58:50.8157 UTC'
+    assert (t + bump).utc_jpl() == 'A.D. 2020-Jun-08 02:58:50.8163 UTC'
